@@ -37,24 +37,32 @@ OC.L10N.register(
     "Bookmark updated" : "Signalibru assignadu",
     "Create bookmark" : "Crea unu signalibru",
     "Takes a link and adds it to your collection of bookmarks." : "Pigat unu ligòngiu e dd'agiunghet a sa colletzione tua de signalibros.",
+    "Do you really want to delete this bookmark?" : "A beru cheres cantzellare custu signalibru?",
+    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
     "Enter new title" : "Inserta unu tìtulu nou",
     "Select bookmark" : "Seletziona signalibru",
     "Details" : "Detàllios",
     "Rename" : "Torra a numenare",
     "Copy link" : "Còpia ligòngiu",
     "Move" : "Tràmuda",
-    "Do you really want to delete this bookmark?" : "A beru cheres cantzellare custu signalibru?",
-    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
     "Content pending" : "Cuntenutu in suspesu",
     "This content is being downloaded for offline use. Please check back later." : "Custu cuntenutu s'est iscarrigadu pro impreu fora de lìnia. Torra a controllare a pustis.",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "Cartellas {folders} e signalibros {bookmarks} seletzionados",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Signalibros %n seletzionados","Seletziona %n signalibros"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Cartella %n seletzionadas","Selected %n folders"],
+    "Do you really want to delete these items?" : "A beru cheres cantzellare custos elementos?",
     "Open all selected" : "Aberi totu is seletzionados",
     "Move selection" : "Tràmuda seletzione",
     "Edit tags of selection" : "Modìfica etichetas de seletzione",
     "Delete selection" : "Cantzella seletzione",
     "Select all" : "Seletziona totu",
     "Cancel selection" : "Annulla seletzione",
-    "Selected {folders} folders and {bookmarks} bookmarks" : "Cartellas {folders} e signalibros {bookmarks} seletzionados",
-    "Do you really want to delete these items?" : "A beru cheres cantzellare custos elementos?",
+    "Sort by created date" : "Assenta segunu data de creatzione",
+    "Sort by last modified" : "Assenta segundu ùrtima modìfica",
+    "Sort by title" : "Assenta segundu tìtulu",
+    "Sort by click count" : "Assenta seguntu contu de incarcos",
+    "Sort by manual order" : "Assenta segundu ordine manuale",
+    "RSS feed copied" : "Sorgente RSS copiada",
     "Go back" : "Bae in segus",
     "Share folder" : "Cumpartzi cartella",
     "Select one or more tags" : "Seletziona una o prus etichetas",
@@ -67,16 +75,12 @@ OC.L10N.register(
     "The RSS feed requires authentication with your Nextcloud credentials" : "Sa fonte RSS rechedet s'autenticatzione cun is credentziales de Nextcloud",
     "Search" : "Chirca",
     "Empty trash bin" : "Bòida s'àliga",
-    "Sort by created date" : "Assenta segunu data de creatzione",
-    "Sort by last modified" : "Assenta segundu ùrtima modìfica",
-    "Sort by title" : "Assenta segundu tìtulu",
-    "Sort by click count" : "Assenta seguntu contu de incarcos",
-    "Sort by manual order" : "Assenta segundu ordine manuale",
-    "RSS feed copied" : "Sorgente RSS copiada",
     "Enter a link" : "Inserta unu ligòngiu",
     "Enter a title" : "Inserta unu tìtulu",
     "No bookmarks found" : "Perunu signalibru agatadu",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} cartellas e {bookmarks} signalibros",
+    "_%n bookmark_::_%n bookmarks_" : ["%n signalibru","%n signalibros"],
+    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
     "Add a bookmark" : "Agiunghe unu signalibru",
     "Import bookmarks" : "Importa signalibros",
     "Sync with your browser" : "Sincroniza cun su navigadore tuo",
@@ -92,6 +96,9 @@ OC.L10N.register(
     "Deleting selection" : "Eliminatzione seletzione",
     "Importing bookmarks" : "Importatzione signalibros",
     "Moving selection" : "Tràmuda de sa seletzione",
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Tràmuda %n cartellas e de calicunu signalibru"," Tràmuda%n de cartellas e de calicunu signalibru"],
+    "_Moving %n folder_::_Moving %n folders_" : ["Tràmuda %n cartella","Tràmuda%n cartellas"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Tràmuda %n signalibru","Tràmuda %n signalibros"],
     "All bookmarks" : "Totu is signalibros",
     "Recent" : "Reghente",
     "Shared with you" : "Cumpartzidu cun tegus",
@@ -105,6 +112,8 @@ OC.L10N.register(
     "No bookmarked files" : "Perunu archìviu de signalibros",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Is signalibros pro archìvios che a fotos o PDF ant a èssere sarvados in automàticu in is archìvios tuos de Nextcloud, in manera chi tue ddos potzas agatare fintzas cando ses fora de lìnia.",
     "No bookmarks here" : "Perunu signalibru inoghe",
+    "Archive path" : "Caminu archìviu",
+    "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
     "Client apps" : "Aplicatziones cliente",
     "Also check out the collection of client apps that integrate with this app: " : "Controlla fintzas sa colletzione de aplicatziones clientes intergradas cun custa aplicatzione",
     "Install web app" : "Installa aplicatzione internet",
@@ -113,8 +122,8 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Agiunghe a {instanceName}",
     "Need help?" : "Boles agiudu?",
-    "Archive path" : "Caminu archìviu",
-    "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
+    "Created {time} ago" : "Creadu {time} a immoe",
+    "Created on {date}" : "Creadu su {date}",
     "Title" : "Tìtulu",
     "Link" : "Ligòngiu",
     "Root folder" : "Cartella sorgente",
@@ -123,10 +132,10 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Notes for this bookmark …" : "Notas pro custu signalibru ...",
     "Archived file" : "Documentu archiviadu",
+    "Open file" : "Aberi archìviu",
     "Download file" : "Iscàrriga archìviu",
     "Open file location" : "Aberi positzione de s'archìviu",
-    "Created {time} ago" : "Creadu {time} a immoe",
-    "Created on {date}" : "Creadu su {date}",
+    "Link copied" : "Ligòngiu copiadu",
     "Owner" : "Mere",
     "Sharing" : "Cumpartzidura",
     "Select a user or group" : "Seletziona un'utente o grupu",
@@ -140,7 +149,8 @@ OC.L10N.register(
     "Allow editing" : "Permite sa modìfica",
     "Allow resharing" : "Permite de torrare a cumpartzire",
     "Remove share" : "Boga cumpartzidura",
-    "Link copied" : "Ligòngiu copiadu",
+    "Failed to save settings" : "No at fatu a sarvare is informatziones",
+    "Failed to load settings" : "Impossìbile carrigare sa cunfiguratzione",
     "Privacy" : "Riservadesa",
     "Enable accessing and collecting information from the web pages you add" : "Abilita s'atzessu a sa regollida de informatziones dae is pàginas internet chi agiùnghes",
     "Performance" : "Atuatzione",
@@ -156,8 +166,6 @@ OC.L10N.register(
     "Webshot" : "Webshot",
     "Webshot API URL" : " API URL Webshot",
     "Pageres CLI" : "Pageres CLI",
-    "Failed to save settings" : "No at fatu a sarvare is informatziones",
-    "Failed to load settings" : "Impossìbile carrigare sa cunfiguratzione",
     "This URL is already bookmarked! Overwrite?" : "Custu URL est giai unu signalibru! Ddu cheres subraiscrìere?",
     "Enter bookmark title" : "Inserta tìtulu de su signalibru",
     "Enter bookmark URL" : "Inserta URL de su signalibru",
