@@ -168,6 +168,10 @@ OC.L10N.register(
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
     "Enable backups" : "啟用備份",
     "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
+    "Context Chat integration" : "情境聊天整合",
+    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "書籤應用程式可自動將書籤網站的文字內容提供給情境聊天，以便根據這些內容發問並獲得答案。只有啟用自動封存時才能使用此功能。",
+    "Context chat is currently not installed, but is required for this feature." : "目前尚未安裝情境聊天，但此功能需要情境聊天。",
+    "Enable Context Chat integration" : "啟用情境聊天整合",
     "Client apps" : "客戶端 apps",
     "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
     "Install web app" : "安裝 web 應用程式",
@@ -180,6 +184,8 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "若您在使用此書籤應用程式時遇到問題或有任何關於改進的想法，請隨時按此處與我們聯絡。",
     "Support this project" : "支援此專案",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我開發呢個「書籤」App 嘅工作係靠自願訂閱模式來維持嘅。如果你覺得我嘅工作有價值，就請支持下我嘅工作。此外，你都可以考慮喺 Nextcloud App 商店裏面，幫呢個 App 寫一個評價。多謝你 💙",
+    "Created {time} ago" : "在 {time} 前創建",
+    "Created on {date}" : "創建於 {date} ",
     "(Empty title)" : "（空的標題）",
     "Title" : "標題",
     "Link" : "連結",
@@ -190,6 +196,7 @@ OC.L10N.register(
     "Notes" : "註釋",
     "Notes for this bookmark …" : "此書籤的註釋...",
     "Archived file" : "已封存檔案",
+    "Open file" : "開啟檔案",
     "Download file" : "下載檔案",
     "Open file location" : "開啟檔案位置",
     "Link copied" : "連結已複製",
@@ -242,7 +249,9 @@ OC.L10N.register(
     "What" : "甚麼",
     "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
     "Failed to count archived bookmarks" : "無法點算已封存的書籤",
+    "Failed to count deleted bookmarks" : "無法統計已刪除的書籤數量",
     "Failed to count duplicated bookmarks" : "無法點算書籤複本",
+    "Failed to count bookmarks" : "無法計算書籤數量",
     "Failed to load bookmark" : "載入書籤失敗",
     "Failed to find existing bookmark" : "尋找現存的書籤失敗",
     "Failed to create bookmark" : "建立書籤失敗",
@@ -250,6 +259,8 @@ OC.L10N.register(
     "Failed to move bookmark" : "移動書籤失敗",
     "Failed to copy bookmark" : "無法複製書籤",
     "Failed to delete bookmark" : "刪除書籤失敗",
+    "Failed to restore bookmark" : "無法還原書籤",
+    "Import successful" : "導入成功",
     "Failed to rename tag" : "重新命名標籤失敗",
     "Failed to load tags" : "載入標記失敗",
     "Failed to load folders" : "載入資料夾失敗",
@@ -257,12 +268,22 @@ OC.L10N.register(
     "Failed to load deleted bookmarks" : "無法加載已刪除書籤",
     "Failed to delete folder" : "刪除資料夾失敗",
     "Failed to move folder" : "無法移動資料夾",
+    "Failed to restore folder" : "無法還原資料夾",
     "Failed to create folder" : "建立資料夾失敗",
+    "Failed to load children order" : "無法加載子排序",
+    "Failed to move parts of selection" : "無法移動部分選擇",
+    "Failed to copy parts of selection" : "無法複製部分選擇",
+    "Failed to delete parts of selection" : "無法刪除部分選擇",
+    "Failed to tag parts of selection" : "無法標籤部分選擇",
     "Failed to fetch bookmarks." : "擷取書籤失敗",
     "Failed to store setting" : "儲存設定失敗",
     "Failed to load setting {key}" : "載入設定失敗 {key}",
+    "Failed to create share for folder {folderId}" : "無法為資料夾 {folderId} 創建分享",
     "Failed to update share {shareId}" : "更新分享失敗 {shareId}",
     "Failed to delete share {shareId}" : "無法刪除分享 {shareId}",
+    "Failed to create public link for folder {folderId}" : "無法為資料夾 {folderId} 創建公共連結",
+    "Failed to delete public link for folder {folderId}" : "無法刪除資料夾 {folderId} 的公共連結",
+    "Failed to permanently delete parts of trash bin" : "無法永久刪除部分回收桶",
     "Create bookmarks for mentioned links" : "為提到的連結建立書籤",
     "No links found in this message" : "此訊息中找不到連結",
     "Bookmarks feed" : "Bookmarks feed"
